@@ -299,8 +299,8 @@ class Worker:
             elif metadata.request is not None:
                 self._process_raw_request(metadata, func)
         except Exception as e:
-            self._record_request_failure(metadata, e)
-            self._record_failure(request_id, e)
+            self.metadata_repository.record_request_failure(metadata, e)
+            self.metadata_repository.record_failure(request_id, e)
 
     def process_poison_messages(self):
         try:
